@@ -1,5 +1,5 @@
 from youtube_autonomous.elements.rules.element_rules import ElementRules
-from youtube_autonomous.segments.enums import EnhancementElementMode
+from youtube_autonomous.segments.enums import EnhancementMode
 
 
 class StockElementRules(ElementRules):
@@ -19,5 +19,5 @@ class StockElementRules(ElementRules):
 
         self.can_be_segment = True
         self.can_be_enhancement_element = True
-        self.valid_enhancement_modes = [EnhancementElementMode.INLINE, EnhancementElementMode.OVERLAY]
-        self.default_enhancement_mode = EnhancementElementMode.OVERLAY
\ No newline at end of file
+        self.valid_enhancement_modes = [EnhancementMode.INLINE, EnhancementMode.OVERLAY]
+        self.default_enhancement_mode = EnhancementMode.OVERLAY
\ No newline at end of file
