@@ -8,10 +8,9 @@ from youtube_autonomous.elements.rules.effect_element_rules import ElementRules
 from youtube_autonomous.elements.rules.rules_checker import RulesChecker
 from youtube_autonomous.segments.builder.config import DEFAULT_SEGMENT_PARTS_FOLDER
 from youtube_autonomous.segments.enums import EnhancementMode, EnhancementType
+from youtube_autonomous.elements.builder.effect_element_builder import EffectElementBuilder
 from yta_multimedia.audio.voice.transcription.stt.whisper import get_transcription_with_timestamps
 from yta_multimedia.audio.sound.generation.sound_generator import SoundGenerator
-from yta_multimedia.video.edition.effect.moviepy.moviepy_effect import MoviepyEffect
-from yta_multimedia.video.edition.effect.video_effect import VideoEffect
 from yta_general_utils.file import copy_file
 from yta_general_utils.file.filename import get_file_extension
 from yta_general_utils.temp import get_temp_filename
@@ -251,13 +250,11 @@ class Segment:
         type and parameters and applies them into the main
         video.
         """
-        # TODO: I need to apply them ordered by start because
-        # if I try to apply an effect in the second 8s when I
-        # didn't enlarge it enough by applying the previous
-        # inline effects, it will fail
-        enhancement_clips = []
+        # I obtain them sorted to start from the first one to apply them
         for enhancement in sorted(self.enhancements, key = lambda enhancement: enhancement.start):
             if enhancement is None:
+                # TODO: This should not exist if I don't have 100 None segments
+                # because of my +100 index identifying strategy
                 continue
 
             enhancement_clip = enhancement.build()
@@ -265,6 +262,13 @@ class Segment:
 
             end = enhancement.start + enhancement.duration
             if enhancement.mode == EnhancementMode.INLINE.value:
+                if enhancement.type in [EnhancementType.EFFECT.value, EnhancementType.EFFECT]:
+                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip', 'duration']
+                    parameters_not_from_extra = ['duration']
+                    parameters = EffectElementBuilder.get_building_parameters(enhancement, parameters_to_ignore, parameters_not_from_extra)
+
+                    enhancement_clip = enhancement_clip.apply(self.video_clip.subclip(enhancement.start, end), **parameters)
+
                 if enhancement.start > 0:
                     self.video_clip = concatenate_videoclips([
                         self.video_clip.subclip(0, enhancement.start),
@@ -276,6 +280,7 @@ class Segment:
                         enhancement_clip,
                         self.video_clip
                     ])
+                # TODO: What about start == clip.duration (?)
             elif enhancement.mode == EnhancementMode.OVERLAY.value:
                 compound_clip = CompositeVideoClip([
                     self.video_clip.subclip(enhancement.start, end),
@@ -303,21 +308,18 @@ class Segment:
                     ])
                 # TODO: Could happen that duration is longer than self.video_clip.duration (?)
             elif enhancement.mode == EnhancementMode.REPLACE.value:
+                # I first build the special ones
                 if enhancement.type in [EnhancementType.EFFECT.value, EnhancementType.EFFECT]:
-                    # TODO: These 'extra_params' must be set and correctly checked before
-                    # Here 'enhancement_clip' is the effect class, so we need to apply it
-                    # correctly
-                    parameters = enhancement.extra_params
+                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip', 'duration']
+                    parameters_not_from_extra = ['duration']
+                    parameters = EffectElementBuilder.get_building_parameters(enhancement, parameters_to_ignore, parameters_not_from_extra)
 
-                    if issubclass(enhancement_clip, MoviepyEffect):
-                        enhancement_clip = enhancement_clip(clip = self.video_clip.subclip(enhancement.start, end), **parameters).apply()
-                    elif issubclass(enhancement_clip, VideoEffect):
-                        enhancement_clip = enhancement_clip(video = self.video_clip.subclip(enhancement.start, end)).apply(**parameters)
-                    # TODO: What about 'BasePositionMoviepyEffect' (?)
+                    enhancement_clip = enhancement_clip.apply(self.video_clip.subclip(enhancement.start, end), **parameters)
                 elif enhancement.type in [EnhancementType.GREENSCREEN.value, EnhancementType.GREENSCREEN]:
                     # TODO: Send parameters (I don't know how actually)
                     enhancement_clip = enhancement_clip.from_video_to_video(self.video_clip.subclip(enhancement.start, end))
 
+                # Then just push the clip when needed
                 if enhancement.start == 0 and enhancement.duration == self.video_clip.duration:
                     self.video_clip = enhancement_clip
                 elif enhancement.start == 0:
