@@ -221,6 +221,7 @@ class Field(Enum):
     ENHANCEMENTS = 'enhancements'
     START = 'start'
     MODE = 'mode'
+    EXTRA_PARAMS = 'extra_params'
 
 class ProjectField(Enum):
     SEGMENTS = Field.SEGMENTS.value
@@ -245,6 +246,7 @@ class SegmentField(Enum):
     AUDIO_NARRATION_FILENAME = Field.AUDIO_NARRATION_FILENAME.value
     MUSIC = Field.MUSIC.value
     ENHANCEMENTS = Field.ENHANCEMENTS.value
+    EXTRA_PARAMS = Field.EXTRA_PARAMS.value
 
 class EnhancementField(Enum):
     """
@@ -263,6 +265,7 @@ class EnhancementField(Enum):
     ENHANCEMENTS = Field.ENHANCEMENTS.value
     START = Field.START.value
     MODE = Field.MODE.value
+    EXTRA_PARAMS = Field.EXTRA_PARAMS.value
 
 class ShortcodeField(Enum):
     """
@@ -281,6 +284,7 @@ class ShortcodeField(Enum):
     ENHANCEMENTS = Field.ENHANCEMENTS.value
     START = Field.START.value
     MODE = Field.MODE.value
+    EXTRA_PARAMS = Field.EXTRA_PARAMS.value
 
 class BuildingField(Enum):
     STATUS = 'status'
@@ -565,7 +569,7 @@ class StringDuration(Enum):
         return duration
     
 class SegmentStringDuration(Enum):
-    pass
+    FILE_DURATION = StringDuration.FILE_DURATION.value
 
     @staticmethod
     def convert_duration(duration: str):
