@@ -67,16 +67,10 @@ class ShortcodeParser:
         # We register each shortcode in provided 'shortcode_tags'
         self.handlers = []
         for shortcode_tag in shortcode_tags:
-            self.__parser.register(lambda shortcodes, pargs, kwargs, context, content: shortcode_tag.handler(shortcodes, pargs, kwargs, context, content), shortcode_tag.tag, f'/{shortcode_tag.tag}')
-
-            # # We have a different handler for each ShortcodeTag type
-            # if shortcode_tag.is_block_scoped():
-            #     if shortcode_tag.tag == 'blocke':
-            #         self.__parser.register(self.__blocke_shortcode_handler, shortcode_tag.tag, f'/{shortcode_tag.tag}')
-            # else:
-            #     # TODO: Please, make this dynamic but I couldn't in the past
-            #     if shortcode_tag.tag == 'meme':
-            #         self.__parser.register(self.__meme_shortcode_handler, shortcode_tag.tag)
+            if shortcode_tag.is_block_scoped():
+                self.__parser.register(lambda pargs, kwargs, context, content: shortcode_tag.handler(self.shortcodes, pargs, kwargs, context, content), shortcode_tag.tag.value, f'/{shortcode_tag.tag.value}')
+            else:
+                self.__parser.register(lambda pargs, kwargs, context: shortcode_tag.handler(self.shortcodes, pargs, kwargs, context, None), shortcode_tag.tag.value)
 
         # Wildcards seems to be not working here so we cannot handle
         # any unknown shortcode by ourselves. It is better to raise
