@@ -14,8 +14,6 @@ from youtube_autonomous.segments.enums import SegmentField, EnhancementField, Pr
 from youtube_autonomous.elements.validator.element_parameter_validator import ElementParameterValidator
 from youtube_autonomous.segments.builder.config import DEFAULT_SEGMENT_PARTS_FOLDER, DEFAULT_PROJECTS_OUTPUT_FOLDER
 from youtube_autonomous.shortcodes.shortcode_parser import ShortcodeParser
-from yta_multimedia.video.edition.effect.moviepy.moviepy_effect import MoviepyEffect
-from yta_multimedia.video.edition.effect.video_effect import VideoEffect
 from yta_general_utils.temp import clean_temp_folder
 from yta_general_utils.programming.path import get_project_abspath
 from yta_general_utils.path import create_file_abspath
@@ -125,6 +123,8 @@ class YoutubeAutonomous:
         # TODO: Check main structure and validate fields
         # TODO: This shortcode parser must have the definitive shortcodes
         # TODO: Shortcode handlers must be working, check Notion (https://www.notion.so/ShortcodeParser-personalizado-10ff5a32d462804d9253e9cb782e5540?pvs=4)
+        # TODO: This shortcode parser must be instantiated once, and this is
+        # being instantiated twice in this file
         shortcode_parser = ShortcodeParser([ShortcodeTag('meme', ShortcodeTagType.SIMPLE)])
 
         for index, segment in enumerate(segments):
@@ -160,10 +160,11 @@ class YoutubeAutonomous:
             # needed fields
             keywords = segment.get(SegmentField.KEYWORDS.value, None)
             if type == SegmentType.PREMADE.value:
-                # This will raise an Exception if no mandatory parameters are given
+                # We avoid 'duration' because we obtain it from main fields
                 PremadeElementBuilder.extract_extra_params(segment, PremadeElementBuilder.premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'duration'])
             elif type == SegmentType.TEXT.value:
-                TextElementBuilder.extract_extra_params(segment, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration'])
+                # We avoid 'text' and 'duration' because we obtain them from main fields
+                TextElementBuilder.extract_extra_params(segment, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration', 'text'])
             # TODO: Validate for another types
             
             for index, enhancement in enumerate(segment.get(SegmentField.ENHANCEMENTS.value, [])):
@@ -208,19 +209,13 @@ class YoutubeAutonomous:
                 # needed fields
                 keywords = enhancement.get(EnhancementField.KEYWORDS.value, None)
                 if enhancement_type == EnhancementType.PREMADE.value:
-                    # This will raise an Exception if no mandatory parameters are given
+                    # We avoid 'duration' because we obtain it from main fields
                     PremadeElementBuilder.extract_extra_params(enhancement, PremadeElementBuilder.premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'duration'])
                 elif enhancement_type == EnhancementType.EFFECT.value:
-                    effect_class = EffectElementBuilder.effect_name_to_class(keywords)
-
-                    if issubclass(effect_class, MoviepyEffect):
-                        # Params are in the init, removing 'clip'
-                        EffectElementBuilder.extract_extra_params(enhancement, effect_class.__init__, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip'])
-                    elif issubclass(effect_class, VideoEffect):
-                        # Params are in the apply, removing 'video'
-                        EffectElementBuilder.extract_extra_params(enhancement, effect_class.apply, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'video'])
+                    EffectElementBuilder.extract_extra_params(enhancement, EffectElementBuilder.effect_name_to_class(keywords).apply, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip'])
                 elif enhancement_type == EnhancementType.TEXT.value:
-                    TextElementBuilder.extract_extra_params(enhancement, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration'])
+                    # We avoid 'text' and 'duration' because we obtain them from main fields
+                    TextElementBuilder.extract_extra_params(enhancement, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration', 'text'])
                 # TODO: Validate for another types
 
             # 4. If doesn't have necessary fields for its type
@@ -248,7 +243,9 @@ class YoutubeAutonomous:
             'segments': None
         }
 
-        shortcode_parser = ShortcodeParser([])
+        # TODO: This shortcode parser must be instantiated once, and this is
+        # being instantiated twice in this file
+        shortcode_parser = ShortcodeParser([ShortcodeTag('meme', ShortcodeTagType.SIMPLE)])
         segments = []
         for segment in json_data['segments']:
             # Manually handle 'narration_text'
